@@ -1,6 +1,7 @@
 import os, sys
 import re
 from collections import OrderedDict
+from datetime import datetime
 try:
     curr_path = os.path.dirname(os.path.abspath(__file__))
     teedoc_project_path = os.path.abspath(os.path.join(curr_path, "..", "..", ".."))
@@ -15,6 +16,7 @@ try:
 except Exception:
     from jupyter_convert import convert_ipynb_to_html
 
+__version__ = "1.1.9"
 
 class Plugin(Plugin_Base):
     name = "teedoc-plugin-jupyter-notebook-parser"
@@ -23,7 +25,7 @@ class Plugin(Plugin_Base):
         "parse_files": ["ipynb"]
     }
 
-    def on_init(self, config, doc_src_path, site_config, logger = None):
+    def on_init(self, config, doc_src_path, site_config, logger = None, multiprocess = True, **kw_args):
         '''
             @config a dict object
             @logger teedoc.logger.Logger object
@@ -38,7 +40,7 @@ class Plugin(Plugin_Base):
 
         
 
-    def on_parse_files(self, files, new_config=None):
+    def on_parse_files(self, files):
         # result, format must be this
         result = {
             "ok": False,
@@ -53,18 +55,45 @@ class Plugin(Plugin_Base):
         # self.logger.d("files: {}".format(files))
         
         for file in files:
+            name = os.path.basename(file)
+            # ignore temp file
+            if name.startswith(".~"):
+                result["htmls"][file] = None
+                continue
             ext = os.path.splitext(file)[1].lower()
             if ext.endswith("ipynb"):
                 html = convert_ipynb_to_html(file)
                 html.body = self._update_link_html(html.body)
+                metadata = html.metadata
+                date = None
+                ts = int(os.stat(file).st_mtime)
+                if "date" in metadata:
+                    date = metadata["date"].strip().lower()
+                    # set date to false to disable date display
+                    if date and (date == "false" or date == "none"):
+                        date = ""
+                    else:
+                        GMT_FORMAT = '%Y-%m-%d'
+                        try:
+                            date_obj = datetime.strptime(date, GMT_FORMAT)
+                            ts = int(date_obj.timestamp())
+                        except Exception as e:
+                            pass
+                if "author" in metadata:
+                    author = metadata["author"]
+                else:
+                    author = ""
                 result["htmls"][file] = {
                     "title": html.title,
                     "desc": html.desc,
                     "keywords": html.keywords,
                     "tags": html.tags,
                     "body": html.body,
+                    "author": author,
+                    "date": date,
+                    "ts": ts,
                     "toc": html.toc,
-                    "metadata": html.metadata,
+                    "metadata": metadata,
                     "raw": html.raw
                 }
             else:
@@ -72,12 +101,12 @@ class Plugin(Plugin_Base):
         result['ok'] = True
         return result
     
-    def on_parse_pages(self, files, new_config=None):
-        result = self.on_parse_files(files, new_config)
+    def on_parse_pages(self, files):
+        result = self.on_parse_files(files)
         return result
 
     
-    def on_add_html_header_items(self):
+    def on_add_html_header_items(self, type_name):
         items = []
         items.append('<meta name="html-generator" content="teedoc-plugin-jupyter-notebook-parser">')
         return items
